# coding: utf-8

"""
    Green Team Clinical API

    The Green Team’s Clinical Data Service API provides defined access to clinical data on ~16,000 ‘HuSH+’ patients with an ‘asthma-like’ phenotype. Users can select input parameters, and the service returns select output based on the input parameters. The input parameters are: age; sex; race; type of visit; and specific ICD and CPT codes1. Based on the input parameters, the service returns the following outpatient parameters: (1) a list of patient IDs and dates of ED and outpatient visits over the 12-month period after diagnosis; and (2) a list of medications prescribed over the 12-month period after diagnosis. The output data are stratified by patients with ≤2 or >2 ED visits over the 12-month period after diagnosis—the primary clinical endpoint used to define, respectively, patients who are ‘responsive’ and ‘non-responsive’ to treatment.

    OpenAPI spec version: 0.0.1
    Contact: champioj@email.unc.edu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Clinical(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, id=None, name=None, tags=None, category=None, status=None, photo_urls=None):
        """
        Clinical - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'int',
            'name': 'str',
            'tags': 'list[Tag]',
            'category': 'Category',
            'status': 'str',
            'photo_urls': 'list[str]'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'tags': 'tags',
            'category': 'category',
            'status': 'status',
            'photo_urls': 'photoUrls'
        }

        self._id = id
        self._name = name
        self._tags = tags
        self._category = category
        self._status = status
        self._photo_urls = photo_urls

    @property
    def id(self):
        """
        Gets the id of this Clinical.

        :return: The id of this Clinical.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Clinical.

        :param id: The id of this Clinical.
        :type: int
        """

        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Clinical.

        :return: The name of this Clinical.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Clinical.

        :param name: The name of this Clinical.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def tags(self):
        """
        Gets the tags of this Clinical.

        :return: The tags of this Clinical.
        :rtype: list[Tag]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """
        Sets the tags of this Clinical.

        :param tags: The tags of this Clinical.
        :type: list[Tag]
        """

        self._tags = tags

    @property
    def category(self):
        """
        Gets the category of this Clinical.

        :return: The category of this Clinical.
        :rtype: Category
        """
        return self._category

    @category.setter
    def category(self, category):
        """
        Sets the category of this Clinical.

        :param category: The category of this Clinical.
        :type: Category
        """

        self._category = category

    @property
    def status(self):
        """
        Gets the status of this Clinical.
        Clinical

        :return: The status of this Clinical.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this Clinical.
        Clinical

        :param status: The status of this Clinical.
        :type: str
        """
        allowed_values = ["available", "pending", "sold"]
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def photo_urls(self):
        """
        Gets the photo_urls of this Clinical.

        :return: The photo_urls of this Clinical.
        :rtype: list[str]
        """
        return self._photo_urls

    @photo_urls.setter
    def photo_urls(self, photo_urls):
        """
        Sets the photo_urls of this Clinical.

        :param photo_urls: The photo_urls of this Clinical.
        :type: list[str]
        """
        if photo_urls is None:
            raise ValueError("Invalid value for `photo_urls`, must not be `None`")

        self._photo_urls = photo_urls

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Clinical):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
