# coding: utf-8

"""
    Green Team Clinical API

    The Green Team’s Clinical Data Service API provides defined access to clinical data on ~16,000 ‘HuSH+’ patients with an ‘asthma-like’ phenotype. Users can select input parameters, and the service returns select output based on the input parameters. The input parameters are: age; sex; race; type of visit; and specific ICD and CPT codes1. Based on the input parameters, the service returns the following outpatient parameters: (1) a list of patient IDs and dates of ED and outpatient visits over the 12-month period after diagnosis; and (2) a list of medications prescribed over the 12-month period after diagnosis. The output data are stratified by patients with ≤2 or >2 ED visits over the 12-month period after diagnosis—the primary clinical endpoint used to define, respectively, patients who are ‘responsive’ and ‘non-responsive’ to treatment.

    OpenAPI spec version: 0.0.1
    Contact: champioj@email.unc.edu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into sdk package
from .models.category import Category
from .models.clinical import Clinical
from .models.tag import Tag

# import apis into sdk package
from .apis.clinical_api import ClinicalApi

# import ApiClient
from .api_client import ApiClient

from .configuration import Configuration

configuration = Configuration()
